[Libreoffice-commits] core.git: include/vcl vcl/generic vcl/headless vcl/inc vcl/quartz vcl/source vcl/unx vcl/win

Chris Sherlock chris.sherlock79 at gmail.com
Sun Jan 10 02:18:24 PST 2016


 include/vcl/font.hxx                    |    4 ++--
 vcl/generic/glyphs/glyphcache.cxx       |    2 +-
 vcl/generic/print/genpspgraphics.cxx    |   10 +++++-----
 vcl/headless/svptext.cxx                |    2 +-
 vcl/inc/PhysicalFontFace.hxx            |    4 ++--
 vcl/inc/cairotextrender.hxx             |    2 +-
 vcl/inc/fontattributes.hxx              |    8 ++++----
 vcl/inc/fontinstance.hxx                |    2 +-
 vcl/inc/fontselect.hxx                  |    2 +-
 vcl/inc/generic/genpspgraphics.h        |    6 +++---
 vcl/inc/generic/glyphcache.hxx          |    4 ++--
 vcl/inc/headless/svpgdi.hxx             |    2 +-
 vcl/inc/quartz/salgdi.h                 |    8 ++++----
 vcl/inc/salgdi.hxx                      |    4 ++--
 vcl/inc/textrender.hxx                  |    2 +-
 vcl/inc/unx/gcach_ftyp.hxx              |   10 +++++-----
 vcl/inc/unx/salgdi.h                    |    4 ++--
 vcl/inc/win/salgdi.h                    |    4 ++--
 vcl/quartz/ctfonts.cxx                  |   10 +++++-----
 vcl/quartz/ctfonts.hxx                  |    2 +-
 vcl/quartz/ctlayout.cxx                 |    2 +-
 vcl/quartz/salgdi.cxx                   |    4 ++--
 vcl/source/font/PhysicalFontFace.cxx    |    4 ++--
 vcl/source/font/fontattributes.cxx      |   10 +++++-----
 vcl/source/font/fontselect.cxx          |    2 +-
 vcl/source/gdi/font.cxx                 |    2 +-
 vcl/source/gdi/pdfwriter_impl.cxx       |    4 ++--
 vcl/source/gdi/pdfwriter_impl.hxx       |    2 +-
 vcl/source/gdi/virdev.cxx               |    2 +-
 vcl/source/outdev/font.cxx              |    6 +++---
 vcl/unx/generic/gdi/cairotextrender.cxx |    8 ++++----
 vcl/unx/generic/gdi/gcach_ftyp.cxx      |   10 +++++-----
 vcl/unx/generic/gdi/salgdi3.cxx         |    2 +-
 vcl/win/gdi/salfont.cxx                 |   30 +++++++++++++++---------------
 34 files changed, 90 insertions(+), 90 deletions(-)

New commits:
commit 36ccb37eee589c444445ab2d05a5c0dff6585a2f
Author: Chris Sherlock <chris.sherlock79 at gmail.com>
Date:   Sun Jan 10 14:01:22 2016 +1100

    vcl: promote ImplFontAttributes to FontAttributes
    
    ImplFontAttributes is no longer merely a pImpl (or "compilation
    firewall", take your pick) but is a fully fledged class in its
    own right that is used by a number of classes, including
    FontSelectPattern, LogicalFontInstance and PhysicalFontFace. Thus
    I'm "promoting" the use of this class in the codebase.
    
    Change-Id: I26866080a64796978d1c25efbcd16e3e6f94aaa5
    Reviewed-on: https://gerrit.libreoffice.org/21305
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Chris Sherlock <chris.sherlock79 at gmail.com>

diff --git a/include/vcl/font.hxx b/include/vcl/font.hxx
index 9c91995..3b58b67 100644
--- a/include/vcl/font.hxx
+++ b/include/vcl/font.hxx
@@ -33,7 +33,7 @@ class SvStream;
 #define FontAlign TextAlign
 
 class Impl_Font;
-class ImplFontAttributes;
+class FontAttributes;
 namespace vcl { class Font; }
 // need to first declare these outside the vcl namespace, or the friend declarations won't work right
 VCL_DLLPUBLIC SvStream&  ReadFont( SvStream& rIStm, vcl::Font& );
@@ -125,7 +125,7 @@ public:
     bool                IsWordLineMode() const;
 
     void                Merge( const Font& rFont );
-    void                GetFontAttributes( ImplFontAttributes& rAttrs ) const;
+    void                GetFontAttributes( FontAttributes& rAttrs ) const;
 
     Font&               operator=( const Font& );
     bool                operator==( const Font& ) const;
diff --git a/vcl/generic/glyphs/glyphcache.cxx b/vcl/generic/glyphs/glyphcache.cxx
index 12788c0..4d13c52 100644
--- a/vcl/generic/glyphs/glyphcache.cxx
+++ b/vcl/generic/glyphs/glyphcache.cxx
@@ -147,7 +147,7 @@ GlyphCache& GlyphCache::GetInstance()
 }
 
 void GlyphCache::AddFontFile( const OString& rNormalizedName, int nFaceNum,
-    sal_IntPtr nFontId, const ImplFontAttributes& rDFA)
+    sal_IntPtr nFontId, const FontAttributes& rDFA)
 {
     if( mpFtManager )
         mpFtManager->AddFontFile( rNormalizedName, nFaceNum, nFontId, rDFA);
diff --git a/vcl/generic/print/genpspgraphics.cxx b/vcl/generic/print/genpspgraphics.cxx
index 420437e..6ce0811 100644
--- a/vcl/generic/print/genpspgraphics.cxx
+++ b/vcl/generic/print/genpspgraphics.cxx
@@ -878,7 +878,7 @@ bool GenPspGraphics::AddTempDevFontHelper( PhysicalFontCollection* pFontCollecti
         aInfo.m_aFamilyName = rFontName;
 
         // inform glyph cache of new font
-        ImplFontAttributes aDFA = GenPspGraphics::Info2FontAttributes( aInfo );
+        FontAttributes aDFA = GenPspGraphics::Info2FontAttributes( aInfo );
         aDFA.IncreaseQualityBy( 5800 );
 
         int nFaceNum = rMgr.getFontFaceNumber( aInfo.m_nID );
@@ -913,14 +913,14 @@ void GenPspGraphics::ClearDevFontCache()
     GlyphCache::GetInstance().ClearFontCache();
 }
 
-void GenPspGraphics::GetFontAttributes( ImplFontAttributes *pFontAttributes, int )
+void GenPspGraphics::GetFontAttributes( FontAttributes *pFontAttributes, int )
 {
     const psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
     psp::PrintFontInfo aInfo;
 
     if (rMgr.getFontInfo (m_pPrinterGfx->GetFontID(), aInfo))
     {
-        ImplFontAttributes aDFA = Info2FontAttributes( aInfo );
+        FontAttributes aDFA = Info2FontAttributes( aInfo );
         *pFontAttributes = aDFA;
         pFontAttributes->SetBuiltInFontFlag( aDFA.IsBuiltInFont() );
         pFontAttributes->SetScalableFlag( true );
@@ -1083,9 +1083,9 @@ void GenPspGraphics::DoGetGlyphWidths( psp::fontID aFont,
     rMgr.getGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
 }
 
-ImplFontAttributes GenPspGraphics::Info2FontAttributes( const psp::FastPrintFontInfo& rInfo )
+FontAttributes GenPspGraphics::Info2FontAttributes( const psp::FastPrintFontInfo& rInfo )
 {
-    ImplFontAttributes aDFA;
+    FontAttributes aDFA;
     aDFA.SetFamilyName( rInfo.m_aFamilyName );
     aDFA.SetStyleName( rInfo.m_aStyleName );
     aDFA.SetFamilyType( rInfo.m_eFamilyStyle );
diff --git a/vcl/headless/svptext.cxx b/vcl/headless/svptext.cxx
index df156ed..4201649 100644
--- a/vcl/headless/svptext.cxx
+++ b/vcl/headless/svptext.cxx
@@ -28,7 +28,7 @@ sal_uInt16 SvpSalGraphics::SetFont( FontSelectPattern* pIFSD, int nFallbackLevel
     return m_aTextRenderImpl.SetFont(pIFSD, nFallbackLevel);
 }
 
-void SvpSalGraphics::GetFontAttributes( ImplFontAttributes* pFontAttributes, int nFallbackLevel )
+void SvpSalGraphics::GetFontAttributes( FontAttributes* pFontAttributes, int nFallbackLevel )
 {
     m_aTextRenderImpl.GetFontAttributes(pFontAttributes, nFallbackLevel);
 }
diff --git a/vcl/inc/PhysicalFontFace.hxx b/vcl/inc/PhysicalFontFace.hxx
index cebb6a0..ebc0d82 100644
--- a/vcl/inc/PhysicalFontFace.hxx
+++ b/vcl/inc/PhysicalFontFace.hxx
@@ -65,7 +65,7 @@ public:
 //      Instead, the logical font names are mapped to physical fonts by
 //      the Java runtime environment.
 
-class VCL_PLUGIN_PUBLIC PhysicalFontFace : public ImplFontAttributes
+class VCL_PLUGIN_PUBLIC PhysicalFontFace : public FontAttributes
 {
 public:
     virtual                ~PhysicalFontFace() {}
@@ -86,7 +86,7 @@ public:
     sal_Int32               CompareIgnoreSize( const PhysicalFontFace& ) const;
 
 protected:
-    explicit                PhysicalFontFace( const ImplFontAttributes& );
+    explicit                PhysicalFontFace( const FontAttributes& );
     void                    SetBitmapSize( int nW, int nH ) { mnWidth=nW; mnHeight=nH; }
 
     long                    mnWidth;    // Width (in pixels)
diff --git a/vcl/inc/cairotextrender.hxx b/vcl/inc/cairotextrender.hxx
index 85cfa08..fdd719b 100644
--- a/vcl/inc/cairotextrender.hxx
+++ b/vcl/inc/cairotextrender.hxx
@@ -89,7 +89,7 @@ public:
 
     virtual void                SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16          SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void                GetFontAttributes( ImplFontAttributes*, int nFallbackLevel ) override;
+    virtual void                GetFontAttributes( FontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool                GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void                GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/fontattributes.hxx b/vcl/inc/fontattributes.hxx
index 2e3290a..9ff1b7c 100644
--- a/vcl/inc/fontattributes.hxx
+++ b/vcl/inc/fontattributes.hxx
@@ -31,11 +31,11 @@
 class OutputDevice;
 class FontSelectPattern;
 
-class ImplFontAttributes
+class FontAttributes
 {
 public:
-    explicit        ImplFontAttributes();
-    explicit        ImplFontAttributes( const FontSelectPattern& );
+    explicit        FontAttributes();
+    explicit        FontAttributes( const FontSelectPattern& );
 
     // device independent font functions
     const OUString& GetFamilyName() const                       { return maFamilyName; }
@@ -60,7 +60,7 @@ public:
 
     void            SetSymbolFlag(const bool bSymbolFlag )      { mbSymbolFlag = bSymbolFlag; }
 
-    bool            CompareDeviceIndependentFontAttributes(const ImplFontAttributes& rOther) const;
+    bool            CompareDeviceIndependentFontAttributes(const FontAttributes& rOther) const;
 
     // Device dependent functions
     int             GetQuality() const                          { return mnQuality; }
diff --git a/vcl/inc/fontinstance.hxx b/vcl/inc/fontinstance.hxx
index 892ce15..c790a92 100644
--- a/vcl/inc/fontinstance.hxx
+++ b/vcl/inc/fontinstance.hxx
@@ -42,7 +42,7 @@ public:
 public: // TODO: make data members private
     ImplFontCache * mpFontCache;
     FontSelectPattern  maFontSelData;          // FontSelectionData
-    ImplFontAttributes  maFontAttributes;       // Font attributes
+    FontAttributes  maFontAttributes;       // Font attributes
     const ConvertChar* mpConversion;           // used e.g. for StarBats->StarSymbol
 
     long            mnLineHeight;
diff --git a/vcl/inc/fontselect.hxx b/vcl/inc/fontselect.hxx
index 0a23105..145989f 100644
--- a/vcl/inc/fontselect.hxx
+++ b/vcl/inc/fontselect.hxx
@@ -33,7 +33,7 @@ class ConvertChar;
 class OutputDevice;
 class Size;
 
-class FontSelectPatternAttributes : public ImplFontAttributes
+class FontSelectPatternAttributes : public FontAttributes
 {
 public:
                     FontSelectPatternAttributes( const vcl::Font&, const OUString& rSearchName,
diff --git a/vcl/inc/generic/genpspgraphics.h b/vcl/inc/generic/genpspgraphics.h
index c1227b7..860f15b 100644
--- a/vcl/inc/generic/genpspgraphics.h
+++ b/vcl/inc/generic/genpspgraphics.h
@@ -34,7 +34,7 @@ class PhysicalFontCollection;
 namespace psp { struct JobData; class PrinterGfx; }
 
 class ServerFont;
-class ImplFontAttributes;
+class FontAttributes;
 class SalInfoPrinter;
 class GlyphCache;
 
@@ -69,7 +69,7 @@ public:
                                               Int32Vector& rWidths,
                                               Ucs2UIntMap& rUnicodeEnc );
 
-    static ImplFontAttributes Info2FontAttributes( const psp::FastPrintFontInfo& );
+    static FontAttributes Info2FontAttributes( const psp::FastPrintFontInfo& );
     static void             AnnounceFonts( PhysicalFontCollection*,
                                            const psp::FastPrintFontInfo& );
 
@@ -92,7 +92,7 @@ public:
 
     virtual void            SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void            GetFontAttributes( ImplFontAttributes*, int nFallbackLevel ) override;
+    virtual void            GetFontAttributes( FontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool            GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void            GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/generic/glyphcache.hxx b/vcl/inc/generic/glyphcache.hxx
index b3666f5..da8f29c 100644
--- a/vcl/inc/generic/glyphcache.hxx
+++ b/vcl/inc/generic/glyphcache.hxx
@@ -63,7 +63,7 @@ public:
     void                    AddFontFile(
                                 const OString& rNormalizedName,
                                 int nFaceNum, sal_IntPtr nFontId,
-                                const ImplFontAttributes&);
+                                const FontAttributes&);
 
     void                    AnnounceFonts( PhysicalFontCollection* ) const;
 
@@ -161,7 +161,7 @@ public:
 
     const FontSelectPattern& GetFontSelData() const      { return maFontSelData; }
 
-    void                    FetchFontAttributes( ImplFontAttributes&, long& rFactor ) const;
+    void                    FetchFontAttributes( FontAttributes&, long& rFactor ) const;
     const unsigned char*    GetTable( const char* pName, sal_uLong* pLength );
     int                     GetEmUnits() const { return maFaceFT->units_per_EM;}
     double                  GetStretch() { return mfStretch; }
diff --git a/vcl/inc/headless/svpgdi.hxx b/vcl/inc/headless/svpgdi.hxx
index e6a6c64..cb04f7b 100644
--- a/vcl/inc/headless/svpgdi.hxx
+++ b/vcl/inc/headless/svpgdi.hxx
@@ -121,7 +121,7 @@ public:
 
     virtual void            SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void            GetFontAttributes( ImplFontAttributes*, int nFallbackLevel ) override;
+    virtual void            GetFontAttributes( FontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void            GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/quartz/salgdi.h b/vcl/inc/quartz/salgdi.h
index 5bfbed2..5d007c7 100644
--- a/vcl/inc/quartz/salgdi.h
+++ b/vcl/inc/quartz/salgdi.h
@@ -46,7 +46,7 @@
 #include <unordered_map>
 
 class AquaSalFrame;
-class ImplFontAttributes;
+class FontAttributes;
 class CoreTextStyle;
 class XorEmulation;
 
@@ -57,7 +57,7 @@ typedef std::vector<unsigned char> ByteVector;
 class CoreTextFontFace : public PhysicalFontFace
 {
 public:
-                                    CoreTextFontFace( const ImplFontAttributes&, sal_IntPtr nFontID );
+                                    CoreTextFontFace( const FontAttributes&, sal_IntPtr nFontID );
     virtual                         ~CoreTextFontFace();
 
     PhysicalFontFace*               Clone() const override;
@@ -94,7 +94,7 @@ public:
 
     SalLayout* GetTextLayout( void ) const;
 
-    void       GetFontAttributes( ImplFontAttributes& ) const;
+    void       GetFontAttributes( FontAttributes& ) const;
     bool       GetGlyphBoundRect( sal_GlyphId, Rectangle& ) const;
     bool       GetGlyphOutline( sal_GlyphId, basegfx::B2DPolyPolygon& ) const;
 
@@ -338,7 +338,7 @@ public:
     // set the font
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
     // get the current font's metrics
-    virtual void            GetFontAttributes( ImplFontAttributes*, int nFallbackLevel ) override;
+    virtual void            GetFontAttributes( FontAttributes*, int nFallbackLevel ) override;
     // get the repertoire of the current font
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool            GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
diff --git a/vcl/inc/salgdi.hxx b/vcl/inc/salgdi.hxx
index b9e4d04..039e45f 100644
--- a/vcl/inc/salgdi.hxx
+++ b/vcl/inc/salgdi.hxx
@@ -41,7 +41,7 @@
 class PhysicalFontCollection;
 class SalBitmap;
 class FontSelectPattern;
-class ImplFontAttributes;
+class FontAttributes;
 class PhysicalFontFace;
 class SalLayout;
 class ImplLayoutArgs;
@@ -145,7 +145,7 @@ public:
     void                        ReleaseFonts() { SetFont( nullptr, 0 ); }
 
     // get the current font's metrics
-    virtual void                GetFontAttributes( ImplFontAttributes*, int nFallbackLevel = 0 ) = 0;
+    virtual void                GetFontAttributes( FontAttributes*, int nFallbackLevel = 0 ) = 0;
 
     // get the repertoire of the current font
     virtual const FontCharMapPtr GetFontCharMap() const = 0;
diff --git a/vcl/inc/textrender.hxx b/vcl/inc/textrender.hxx
index f49403d..11a38cb 100644
--- a/vcl/inc/textrender.hxx
+++ b/vcl/inc/textrender.hxx
@@ -42,7 +42,7 @@ public:
 
     virtual void                    SetTextColor( SalColor nSalColor ) = 0;
     virtual sal_uInt16              SetFont( FontSelectPattern*, int nFallbackLevel ) = 0;
-    virtual void                    GetFontAttributes( ImplFontAttributes*, int nFallbackLevel ) = 0;
+    virtual void                    GetFontAttributes( FontAttributes*, int nFallbackLevel ) = 0;
     virtual const FontCharMapPtr    GetFontCharMap() const = 0;
     virtual bool                    GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const = 0;
     virtual void                    GetDevFontList( PhysicalFontCollection* ) = 0;
diff --git a/vcl/inc/unx/gcach_ftyp.hxx b/vcl/inc/unx/gcach_ftyp.hxx
index 084ea03..dae148d 100644
--- a/vcl/inc/unx/gcach_ftyp.hxx
+++ b/vcl/inc/unx/gcach_ftyp.hxx
@@ -58,7 +58,7 @@ private:
 class FreetypeFontInfo
 {
 public:
-                           FreetypeFontInfo( const ImplFontAttributes&,
+                           FreetypeFontInfo( const FontAttributes&,
                                const OString& rNativeFileName,
                                int nFaceNum, sal_IntPtr nFontId);
                           ~FreetypeFontInfo();
@@ -74,7 +74,7 @@ public:
     const OString&        GetFontFileName() const   { return mpFontFile->GetFileName(); }
     sal_IntPtr            GetFontId() const         { return mnFontId; }
     bool                  IsSymbolFont() const      { return maDevFontAttributes.IsSymbolFont(); }
-    const ImplFontAttributes& GetFontAttributes() const { return maDevFontAttributes; }
+    const FontAttributes& GetFontAttributes() const { return maDevFontAttributes; }
 
     void                  AnnounceFont( PhysicalFontCollection* );
 
@@ -94,7 +94,7 @@ private:
     GraphiteFaceWrapper * mpGraphiteFace;
 #endif
     sal_IntPtr      mnFontId;
-    ImplFontAttributes maDevFontAttributes;
+    FontAttributes maDevFontAttributes;
 
     FontCharMapPtr  mpFontCharMap;
 
@@ -133,7 +133,7 @@ public:
                         ~FreetypeManager();
 
     void                AddFontFile( const OString& rNormalizedName,
-                            int nFaceNum, sal_IntPtr nFontId, const ImplFontAttributes&);
+                            int nFaceNum, sal_IntPtr nFontId, const FontAttributes&);
     void                AnnounceFonts( PhysicalFontCollection* ) const;
     void                ClearFontList();
 
@@ -152,7 +152,7 @@ private:
     FreetypeFontInfo*             mpFreetypeFontInfo;
 
 public:
-                            FreetypeFontFace( FreetypeFontInfo*, const ImplFontAttributes& );
+                            FreetypeFontFace( FreetypeFontInfo*, const FontAttributes& );
 
     virtual LogicalFontInstance* CreateFontInstance( FontSelectPattern& ) const override;
     virtual PhysicalFontFace* Clone() const override   { return new FreetypeFontFace( *this ); }
diff --git a/vcl/inc/unx/salgdi.h b/vcl/inc/unx/salgdi.h
index b68ea38..68a3bce 100644
--- a/vcl/inc/unx/salgdi.h
+++ b/vcl/inc/unx/salgdi.h
@@ -36,7 +36,7 @@
 #include <deque>
 #include <memory>
 
-class ImplFontAttributes;
+class FontAttributes;
 class FontSelectPattern;
 class SalBitmap;
 class SalColormap;
@@ -112,7 +112,7 @@ public:
 
     virtual void                    SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16              SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void                    GetFontAttributes( ImplFontAttributes*, int nFallbackLevel ) override;
+    virtual void                    GetFontAttributes( FontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr    GetFontCharMap() const override;
     virtual bool                    GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void                    GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/win/salgdi.h b/vcl/inc/win/salgdi.h
index 00931f0..e35b71d 100644
--- a/vcl/inc/win/salgdi.h
+++ b/vcl/inc/win/salgdi.h
@@ -74,7 +74,7 @@ private:
 class WinFontFace : public PhysicalFontFace
 {
 public:
-    explicit                WinFontFace( const ImplFontAttributes&,
+    explicit                WinFontFace( const FontAttributes&,
                                 int nFontHeight, BYTE eWinCharSet,
                                 BYTE nPitchAndFamily  );
     virtual                 ~WinFontFace();
@@ -361,7 +361,7 @@ public:
     // set the font
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
     // get the current font's metrics
-    virtual void            GetFontAttributes( ImplFontAttributes*, int nFallbackLevel ) override;
+    virtual void            GetFontAttributes( FontAttributes*, int nFallbackLevel ) override;
     // get the repertoire of the current font
     virtual const FontCharMapPtr GetFontCharMap() const override;
     // get the layout capabilities of the current font
diff --git a/vcl/quartz/ctfonts.hxx b/vcl/quartz/ctfonts.hxx
index 1752f17..983437c 100644
--- a/vcl/quartz/ctfonts.hxx
+++ b/vcl/quartz/ctfonts.hxx
@@ -27,7 +27,7 @@
 #include "sallayout.hxx"
 
 SystemFontList* GetCoretextFontList();
-ImplFontAttributes DevFontFromCTFontDescriptor( CTFontDescriptorRef, bool* );
+FontAttributes DevFontFromCTFontDescriptor( CTFontDescriptorRef, bool* );
 
 #endif // INCLUDED_VCL_QUARTZ_CTFONTS_HXX
 
diff --git a/vcl/quartz/ctlayout.cxx b/vcl/quartz/ctlayout.cxx
index 5b0d98e..2b0eedb 100644
--- a/vcl/quartz/ctlayout.cxx
+++ b/vcl/quartz/ctlayout.cxx
@@ -492,7 +492,7 @@ int CTLayout::GetNextGlyphs( int nLen, sal_GlyphId* pOutGlyphIds, Point& rPos, i
     const PhysicalFontFace* pFallbackFont = nullptr;
     CTFontRef pFont = nullptr;
     CTFontDescriptorRef pFontDesc = nullptr;
-    ImplFontAttributes rDevFontAttr;
+    FontAttributes rDevFontAttr;
 
     boost::ptr_vector<CTRunData>::const_iterator iter = m_vRunData.begin();
 
diff --git a/vcl/quartz/salgdi.cxx b/vcl/quartz/salgdi.cxx
index 7742523..334eea1 100644
--- a/vcl/quartz/salgdi.cxx
+++ b/vcl/quartz/salgdi.cxx
@@ -64,7 +64,7 @@ CoreTextFontFace::CoreTextFontFace( const CoreTextFontFace& rSrc )
         mpCharMap = rSrc.mpCharMap;
 }
 
-CoreTextFontFace::CoreTextFontFace( const ImplFontAttributes& rDFA, sal_IntPtr nFontId )
+CoreTextFontFace::CoreTextFontFace( const FontAttributes& rDFA, sal_IntPtr nFontId )
   : PhysicalFontFace( rDFA )
   , mnFontId( nFontId )
   , mbOs2Read( false )
@@ -306,7 +306,7 @@ void AquaSalGraphics::SetTextColor( SalColor nSalColor )
     // SAL_ DEBUG(std::hex << nSalColor << std::dec << "={" << maTextColor.GetRed() << ", " << maTextColor.GetGreen() << ", " << maTextColor.GetBlue() << ", " << maTextColor.GetAlpha() << "}");
 }
 
-void AquaSalGraphics::GetFontAttributes( ImplFontAttributes* pFontAttributes, int /*nFallbackLevel*/ )
+void AquaSalGraphics::GetFontAttributes( FontAttributes* pFontAttributes, int /*nFallbackLevel*/ )
 {
     mpTextStyle->GetFontAttributes( *pFontAttributes );
 }
diff --git a/vcl/source/font/PhysicalFontFace.cxx b/vcl/source/font/PhysicalFontFace.cxx
index c5194fb..9540604 100644
--- a/vcl/source/font/PhysicalFontFace.cxx
+++ b/vcl/source/font/PhysicalFontFace.cxx
@@ -26,8 +26,8 @@
 
 #include "PhysicalFontFace.hxx"
 
-PhysicalFontFace::PhysicalFontFace( const ImplFontAttributes& rDFA )
-    : ImplFontAttributes( rDFA )
+PhysicalFontFace::PhysicalFontFace( const FontAttributes& rDFA )
+    : FontAttributes( rDFA )
     , mnWidth(0)
     , mnHeight(0)
 {
diff --git a/vcl/source/font/fontattributes.cxx b/vcl/source/font/fontattributes.cxx
index d823748..be3ab68 100644
--- a/vcl/source/font/fontattributes.cxx
+++ b/vcl/source/font/fontattributes.cxx
@@ -63,7 +63,7 @@ using namespace ::com::sun::star::uno;
 using namespace ::rtl;
 using namespace ::utl;
 
-bool ImplFontAttributes::CompareDeviceIndependentFontAttributes(const ImplFontAttributes& rOther) const
+bool FontAttributes::CompareDeviceIndependentFontAttributes(const FontAttributes& rOther) const
 {
     if (maFamilyName != rOther.maFamilyName)
         return false;
@@ -92,7 +92,7 @@ bool ImplFontAttributes::CompareDeviceIndependentFontAttributes(const ImplFontAt
     return true;
 }
 
-ImplFontAttributes::ImplFontAttributes()
+FontAttributes::FontAttributes()
     : mnWidth ( 0 )
     , mnOrientation( 0 )
     , mnAscent( 0 )
@@ -135,7 +135,7 @@ ImplFontAttributes::ImplFontAttributes()
     // empty
 }
 
-ImplFontAttributes::ImplFontAttributes( const FontSelectPattern& rFontSelData )
+FontAttributes::FontAttributes( const FontSelectPattern& rFontSelData )
     : mnWidth ( rFontSelData.mnWidth )
     , mnOrientation( (short)(rFontSelData.mnOrientation) )
     , mnAscent( 0 )
@@ -194,7 +194,7 @@ ImplFontAttributes::ImplFontAttributes( const FontSelectPattern& rFontSelData )
 }
 
 
-void ImplFontAttributes::ImplInitTextLineSize( const OutputDevice* pDev )
+void FontAttributes::ImplInitTextLineSize( const OutputDevice* pDev )
 {
     long nDescent = mnDescent;
     if ( nDescent <= 0 )
@@ -295,7 +295,7 @@ void ImplFontAttributes::ImplInitTextLineSize( const OutputDevice* pDev )
 
 }
 
-void ImplFontAttributes::ImplInitAboveTextLineSize()
+void FontAttributes::ImplInitAboveTextLineSize()
 {
     long nIntLeading = mnIntLeading;
     // TODO: assess usage of nLeading below (changed in extleading CWS)
diff --git a/vcl/source/font/fontselect.cxx b/vcl/source/font/fontselect.cxx
index 53fd491..641e3c6 100644
--- a/vcl/source/font/fontselect.cxx
+++ b/vcl/source/font/fontselect.cxx
@@ -109,7 +109,7 @@ FontSelectPatternAttributes::FontSelectPatternAttributes( const vcl::Font& rFont
 #ifdef WNT
 FontSelectPatternAttributes::FontSelectPatternAttributes( const PhysicalFontFace& rFontData,
     const Size& rSize, float fExactHeight, int nOrientation, bool bVertical )
-    : ImplFontAttributes( rFontData )
+    : FontAttributes( rFontData )
     , mnWidth( rSize.Width() )
     , mnHeight( rSize.Height() )
     , mfExactHeight( fExactHeight )
diff --git a/vcl/source/gdi/font.cxx b/vcl/source/gdi/font.cxx
index d6b561e..6e9f45f 100644
--- a/vcl/source/gdi/font.cxx
+++ b/vcl/source/gdi/font.cxx
@@ -608,7 +608,7 @@ void Font::Merge( const vcl::Font& rFont )
     SetRelief( rFont.GetRelief() );
 }
 
-void Font::GetFontAttributes( ImplFontAttributes& rAttrs ) const
+void Font::GetFontAttributes( FontAttributes& rAttrs ) const
 {
     rAttrs.SetFamilyName( mpImplFont->maFamilyName );
     rAttrs.SetStyleName( mpImplFont->maStyleName );
diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index 9930d977..f9d3fbd 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -2240,9 +2240,9 @@ OutputDevice* PDFWriterImpl::getReferenceDevice()
     return m_pReferenceDevice;
 }
 
-static ImplFontAttributes GetDevFontAttributes( const PDFWriterImpl::BuiltinFont& rBuiltin )
+static FontAttributes GetDevFontAttributes( const PDFWriterImpl::BuiltinFont& rBuiltin )
 {
-    ImplFontAttributes aDFA;
+    FontAttributes aDFA;
     aDFA.SetFamilyName( OUString::createFromAscii( rBuiltin.m_pName ) );
     aDFA.SetStyleName( OUString::createFromAscii( rBuiltin.m_pStyleName ) );
     aDFA.SetFamilyType( rBuiltin.m_eFamily );
diff --git a/vcl/source/gdi/pdfwriter_impl.hxx b/vcl/source/gdi/pdfwriter_impl.hxx
index 1210759..1a30f2f 100644
--- a/vcl/source/gdi/pdfwriter_impl.hxx
+++ b/vcl/source/gdi/pdfwriter_impl.hxx
@@ -47,7 +47,7 @@
 
 class StyleSettings;
 class FontSelectPattern;
-class ImplFontAttributes;
+class FontAttributes;
 class FontSubsetInfo;
 class ZCodec;
 class EncHashTransporter;
diff --git a/vcl/source/gdi/virdev.cxx b/vcl/source/gdi/virdev.cxx
index abd8a2e..e3e129e 100644
--- a/vcl/source/gdi/virdev.cxx
+++ b/vcl/source/gdi/virdev.cxx
@@ -564,7 +564,7 @@ long VirtualDevice::GetFontExtLeading() const
 #endif
 
     LogicalFontInstance* pFontInstance = mpFontInstance;
-    ImplFontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
+    FontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
 
     return pFontAttributes->GetExternalLeading();
 }
diff --git a/vcl/source/outdev/font.cxx b/vcl/source/outdev/font.cxx
index 80c85fc..3ded83f 100644
--- a/vcl/source/outdev/font.cxx
+++ b/vcl/source/outdev/font.cxx
@@ -190,7 +190,7 @@ FontMetric OutputDevice::GetFontMetric() const
         return aMetric;
 
     LogicalFontInstance* pFontInstance = mpFontInstance;
-    ImplFontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
+    FontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
 
     // prepare metric
     aMetric.Font::operator=( maFont );
@@ -486,7 +486,7 @@ FontEmphasisMark OutputDevice::ImplGetEmphasisMarkStyle( const vcl::Font& rFont
 long OutputDevice::GetFontExtLeading() const
 {
     LogicalFontInstance*      pFontInstance = mpFontInstance;
-    ImplFontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
+    FontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
 
     return pFontAttributes->GetExternalLeading();
 }
@@ -1464,7 +1464,7 @@ long OutputDevice::GetMinKashida() const
         return 0;
 
     LogicalFontInstance* pFontInstance = mpFontInstance;
-    ImplFontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
+    FontAttributes* pFontAttributes = &(pFontInstance->maFontAttributes);
     return ImplDevicePixelToLogicWidth( pFontAttributes->GetMinKashida() );
 }
 
diff --git a/vcl/unx/generic/gdi/cairotextrender.cxx b/vcl/unx/generic/gdi/cairotextrender.cxx
index e574011..c68c23c 100644
--- a/vcl/unx/generic/gdi/cairotextrender.cxx
+++ b/vcl/unx/generic/gdi/cairotextrender.cxx
@@ -99,7 +99,7 @@ bool CairoTextRender::setFont( const FontSelectPattern *pEntry, int nFallbackLev
     return false;
 }
 
-FontConfigFontOptions* GetFCFontOptions( const ImplFontAttributes& rFontAttributes, int nSize);
+FontConfigFontOptions* GetFCFontOptions( const FontAttributes& rFontAttributes, int nSize);
 
 void ServerFontInstance::HandleFontOptions()
 {
@@ -416,7 +416,7 @@ void CairoTextRender::GetDevFontList( PhysicalFontCollection* pFontCollection )
         int nFaceNum = rMgr.getFontFaceNumber( aInfo.m_nID );
 
         // inform GlyphCache about this font provided by the PsPrint subsystem
-        ImplFontAttributes aDFA = GenPspGraphics::Info2FontAttributes( aInfo );
+        FontAttributes aDFA = GenPspGraphics::Info2FontAttributes( aInfo );
         aDFA.IncreaseQualityBy( 4096 );
         const OString& rFileName = rMgr.getFontFileSysPath( aInfo.m_nID );
         rGC.AddFontFile( rFileName, nFaceNum, aInfo.m_nID, aDFA );
@@ -440,7 +440,7 @@ void cairosubcallback(void* pPattern)
     cairo_ft_font_options_substitute(pFontOptions, static_cast<FcPattern*>(pPattern));
 }
 
-FontConfigFontOptions* GetFCFontOptions( const ImplFontAttributes& rFontAttributes, int nSize)
+FontConfigFontOptions* GetFCFontOptions( const FontAttributes& rFontAttributes, int nSize)
 {
     psp::FastPrintFontInfo aInfo;
 
@@ -453,7 +453,7 @@ FontConfigFontOptions* GetFCFontOptions( const ImplFontAttributes& rFontAttribut
 }
 
 void
-CairoTextRender::GetFontAttributes( ImplFontAttributes *pFontAttributes, int nFallbackLevel )
+CairoTextRender::GetFontAttributes( FontAttributes *pFontAttributes, int nFallbackLevel )
 {
     if( nFallbackLevel >= MAX_FALLBACK )
         return;
diff --git a/vcl/unx/generic/gdi/gcach_ftyp.cxx b/vcl/unx/generic/gdi/gcach_ftyp.cxx
index 0bda2ef..1853a91 100644
--- a/vcl/unx/generic/gdi/gcach_ftyp.cxx
+++ b/vcl/unx/generic/gdi/gcach_ftyp.cxx
@@ -196,7 +196,7 @@ const void * graphiteFontTable(const void* appFaceHandle, unsigned int name, siz
 }
 #endif
 
-FreetypeFontInfo::FreetypeFontInfo( const ImplFontAttributes& rDevFontAttributes,
+FreetypeFontInfo::FreetypeFontInfo( const FontAttributes& rDevFontAttributes,
     const OString& rNativeFileName, int nFaceNum, sal_IntPtr nFontId)
 :
     maFaceFT( nullptr ),
@@ -372,7 +372,7 @@ FreetypeManager::~FreetypeManager()
 }
 
 void FreetypeManager::AddFontFile( const OString& rNormalizedName,
-    int nFaceNum, sal_IntPtr nFontId, const ImplFontAttributes& rDevFontAttr)
+    int nFaceNum, sal_IntPtr nFontId, const FontAttributes& rDevFontAttr)
 {
     if( rNormalizedName.isEmpty() )
         return;
@@ -424,7 +424,7 @@ ServerFont* FreetypeManager::CreateFont( const FontSelectPattern& rFSD )
     return pNew;
 }
 
-FreetypeFontFace::FreetypeFontFace( FreetypeFontInfo* pFI, const ImplFontAttributes& rDFA )
+FreetypeFontFace::FreetypeFontFace( FreetypeFontInfo* pFI, const FontAttributes& rDFA )
 :   PhysicalFontFace( rDFA ),
     mpFreetypeFontInfo( pFI )
 {
@@ -613,9 +613,9 @@ ServerFont::~ServerFont()
 }
 
 
-void ServerFont::FetchFontAttributes( ImplFontAttributes& rTo, long& rFactor ) const
+void ServerFont::FetchFontAttributes( FontAttributes& rTo, long& rFactor ) const
 {
-    static_cast<ImplFontAttributes&>(rTo) = mpFontInfo->GetFontAttributes();
+    static_cast<FontAttributes&>(rTo) = mpFontInfo->GetFontAttributes();
 
     rTo.SetScalableFlag( true ); // FIXME: Shouldn't this check FT_IS_SCALABLE( maFaceFT )?
     rTo.SetTrueTypeFlag( FT_IS_SFNT( maFaceFT ) != 0 );
diff --git a/vcl/unx/generic/gdi/salgdi3.cxx b/vcl/unx/generic/gdi/salgdi3.cxx
index ae63464..9a45d11 100644
--- a/vcl/unx/generic/gdi/salgdi3.cxx
+++ b/vcl/unx/generic/gdi/salgdi3.cxx
@@ -136,7 +136,7 @@ void X11SalGraphics::GetDevFontList( PhysicalFontCollection* pFontCollection )
 }
 
 void
-X11SalGraphics::GetFontAttributes( ImplFontAttributes *pFontAttributes, int nFallbackLevel )
+X11SalGraphics::GetFontAttributes( FontAttributes *pFontAttributes, int nFallbackLevel )
 {
     mxTextRenderImpl->GetFontAttributes(pFontAttributes, nFallbackLevel);
 }
diff --git a/vcl/quartz/ctfonts.cxx b/vcl/quartz/ctfonts.cxx
index e33ce7e..5052f78 100644
--- a/vcl/quartz/ctfonts.cxx
+++ b/vcl/quartz/ctfonts.cxx
@@ -117,7 +117,7 @@ CoreTextStyle::~CoreTextStyle()
         CFRelease( mpStyleDict );
 }
 
-void CoreTextStyle::GetFontAttributes( ImplFontAttributes& rFontAttributes ) const
+void CoreTextStyle::GetFontAttributes( FontAttributes& rFontAttributes ) const
 {
     // get the matching CoreText font handle
     // TODO: is it worth it to cache the CTFontRef in SetFont() and reuse it here?
@@ -130,7 +130,7 @@ void CoreTextStyle::GetFontAttributes( ImplFontAttributes& rFontAttributes ) con
     rFontAttributes.SetExternalLeading( lrint( CTFontGetLeading( aCTFontRef )) );
     rFontAttributes.SetInternalLeading( lrint( fAscent - fCapHeight ) );
 
     // since ImplFontAttributes::mnWidth is only used for stretching/squeezing fonts
     // setting this width to the pixel height of the fontsize is good enough
     // it also makes the calculation of the stretch factor simple
     rFontAttributes.SetWidth( lrint( CTFontGetSize( aCTFontRef ) * mfFontStretch) );
@@ -274,10 +274,10 @@ int CoreTextFontFace::GetFontTable( const char pTagName[5], unsigned char* pResu
     return (int)nByteLength;
 }
 
-ImplFontAttributes DevFontFromCTFontDescriptor( CTFontDescriptorRef pFD, bool* bFontEnabled )
+FontAttributes DevFontFromCTFontDescriptor( CTFontDescriptorRef pFD, bool* bFontEnabled )
 {
     // all CoreText fonts are device fonts that can rotate just fine
-    ImplFontAttributes rDFA;
+    FontAttributes rDFA;
     rDFA.SetOrientationFlag( true );
     rDFA.SetBuiltInFontFlag( true );
     rDFA.SetQuality( 0 );
@@ -415,7 +415,7 @@ static void CTFontEnumCallBack( const void* pValue, void* pContext )
     CTFontDescriptorRef pFD = static_cast<CTFontDescriptorRef>(pValue);
 
     bool bFontEnabled;
-    ImplFontAttributes rDFA = DevFontFromCTFontDescriptor( pFD, &bFontEnabled );
+    FontAttributes rDFA = DevFontFromCTFontDescriptor( pFD, &bFontEnabled );
 
     if( bFontEnabled)
     {
@@ -130,7 +130,7 @@ void CoreTextStyle::GetFontAttributes( ImplFontAttributes& rFontAttributes ) con
     rFontAttributes.SetInternalLeading( lrint( fAscent - fCapHeight ) );
 
-    // since ImplFontAttributes::mnWidth is only used for stretching/squeezing fonts
+    // since FontAttributes::mnWidth is only used for stretching/squeezing fonts
     // setting this width to the pixel height of the fontsize is good enough
     // it also makes the calculation of the stretch factor simple
diff --git a/vcl/win/gdi/salfont.cxx b/vcl/win/gdi/salfont.cxx
index 9c917f3..9e3bce6 100644
--- a/vcl/win/gdi/salfont.cxx
+++ b/vcl/win/gdi/salfont.cxx
@@ -73,7 +73,7 @@ static bool bImplSalCourierScalable = false;
 static bool bImplSalCourierNew = false;
 
 // TODO: also support temporary TTC font files
-typedef std::map< OUString, ImplFontAttributes > FontAttrMap;
+typedef std::map< OUString, FontAttributes > FontAttrMap;
 
 class ImplFontAttrCache
 {
@@ -93,8 +93,8 @@ public:
                               const OUString& rBaseURL);
             ~ImplFontAttrCache();
 
-    ImplFontAttributes  GetFontAttr( const OUString& rFontFileName ) const;
-    void                   AddFontAttr( const OUString& rFontFileName, const ImplFontAttributes& );
+    FontAttributes  GetFontAttr( const OUString& rFontFileName ) const;
+    void                   AddFontAttr( const OUString& rFontFileName, const FontAttributes& );
 };
 
 ImplFontAttrCache::ImplFontAttrCache( const OUString& rFileNameURL, const OUString& rBaseURL ) : aBaseURL( rBaseURL )
@@ -116,7 +116,7 @@ ImplFontAttrCache::ImplFontAttrCache( const OUString& rFileNameURL, const OUStri
 
     // read the cache entries from the file
     OUString aFontFileURL;
-    ImplFontAttributes aDFA;
+    FontAttributes aDFA;
     for(;;)
     {
         aFontFileURL = read_uInt16_lenPrefixed_uInt8s_ToOUString(aCacheFile, RTL_TEXTENCODING_UTF8);
@@ -161,7 +161,7 @@ ImplFontAttrCache::~ImplFontAttrCache()
             while ( aIter != aFontAttributes.end() )
             {
                 const OUString rFontFileURL( (*aIter).first );
-                const ImplFontAttributes& rDFA( (*aIter).second );
+                const FontAttributes& rDFA( (*aIter).second );
                 write_uInt16_lenPrefixed_uInt8s_FromOUString(aCacheFile, rFontFileURL, RTL_TEXTENCODING_UTF8);
                 write_uInt16_lenPrefixed_uInt8s_FromOUString(aCacheFile, rDFA.GetFamilyName(), RTL_TEXTENCODING_UTF8);
 
@@ -190,9 +190,9 @@ OUString ImplFontAttrCache::OptimizeURL( const OUString& rURL ) const
     return aOptimizedFontFileURL;
 }
 
-ImplFontAttributes ImplFontAttrCache::GetFontAttr( const OUString& rFontFileName ) const
+FontAttributes ImplFontAttrCache::GetFontAttr( const OUString& rFontFileName ) const
 {
-    ImplFontAttributes aDFA;
+    FontAttributes aDFA;
     FontAttrMap::const_iterator it = aFontAttributes.find( OptimizeURL( rFontFileName ) );
     if( it != aFontAttributes.end() )
     {
@@ -201,7 +201,7 @@ ImplFontAttributes ImplFontAttrCache::GetFontAttr( const OUString& rFontFileName
     return aDFA;
 }
 
-void ImplFontAttrCache::AddFontAttr( const OUString& rFontFileName, const ImplFontAttributes& rDFA )
+void ImplFontAttrCache::AddFontAttr( const OUString& rFontFileName, const FontAttributes& rDFA )
 {
     SAL_WARN_IF(rFontFileName.isEmpty() || rDFA.GetFamilyName().isEmpty(),
         "vcl.gdi", "ImplFontNameCache::AddFontName - invalid data!");
@@ -770,10 +770,10 @@ inline BYTE ImplPitchToWin( FontPitch ePitch )
         return DEFAULT_PITCH;
 }
 
-static ImplFontAttributes WinFont2DevFontAttributes( const ENUMLOGFONTEXW& rEnumFont,
+static FontAttributes WinFont2DevFontAttributes( const ENUMLOGFONTEXW& rEnumFont,
     const NEWTEXTMETRICW& rMetric, DWORD nFontType )
 {
-    ImplFontAttributes aDFA;
+    FontAttributes aDFA;
 
     const LOGFONTW rLogFont = rEnumFont.elfLogFont;
 
@@ -994,7 +994,7 @@ const void * GrFontData::getTable(unsigned int name, size_t *len) const
 }
 #endif
 
-WinFontFace::WinFontFace( const ImplFontAttributes& rDFS,
+WinFontFace::WinFontFace( const FontAttributes& rDFS,
     int nHeight, BYTE eWinCharSet, BYTE nPitchAndFamily )
 :   PhysicalFontFace( rDFS ),
     mnId( 0 ),
@@ -1477,7 +1477,7 @@ sal_uInt16 WinSalGraphics::SetFont( FontSelectPattern* pFont, int nFallbackLevel
         return 0;
 }
 
-void WinSalGraphics::GetFontAttributes( ImplFontAttributes* pFontAttributes, int nFallbackLevel )
+void WinSalGraphics::GetFontAttributes( FontAttributes* pFontAttributes, int nFallbackLevel )
 {
     // temporarily change the HDC to the font in the fallback level
     HFONT hOldFont = SelectFont( getHDC(), mhFonts[nFallbackLevel] );
@@ -1692,7 +1692,7 @@ void ImplReleaseTempFonts( SalData& rSalData )
 }
 
 static bool ImplGetFontAttrFromFile( const OUString& rFontFileURL,
-    ImplFontAttributes& rDFA )
+    FontAttributes& rDFA )
 {
     OUString aUSytemPath;
     OSL_VERIFY( !osl::FileBase::getSystemPathFromFileURL( rFontFileURL, aUSytemPath ) );
@@ -1790,7 +1790,7 @@ bool WinSalGraphics::AddTempDevFont( PhysicalFontCollection* pFontCollection,
 {
     SAL_INFO( "vcl.gdi", "WinSalGraphics::AddTempDevFont(): " << OUStringToOString( rFontFileURL, RTL_TEXTENCODING_UTF8 ).getStr() );
 
-    ImplFontAttributes aDFA;
+    FontAttributes aDFA;
     aDFA.SetFamilyName(rFontName);
     aDFA.SetQuality( 1000 );
     aDFA.SetBuiltInFontFlag( true );
@@ -1825,7 +1825,7 @@ bool WinSalGraphics::AddTempDevFont( PhysicalFontCollection* pFontCollection,
     aDFA.SetEmbeddableFlag( false );
 
     /*
     // TODO: improve ImplFontAttributes using the "font resource file"
     aDFS.maName = // using "FONTRES:" from file
     if( rFontName != aDFS.maName )
         aDFS.maMapName = aFontName;
@@ -1825,7 +1825,7 @@ bool WinSalGraphics::AddTempDevFont( PhysicalFontCollection* pFontCollection,
 
     /*
-    // TODO: improve ImplFontAttributes using the "font resource file"
+    // TODO: improve FontAttributes using the "font resource file"
     aDFS.maName = // using "FONTRES:" from file
     if( rFontName != aDFS.maName )


More information about the Libreoffice-commits mailing list